@@ -36,7 +36,7 @@ end
 function tools.make_dir(directory)
    assert(directory)
    directory = dir.normalize(directory)
-   fs.execute_quiet(vars.MKDIR.." -p ", directory)
+   fs.execute_quiet(vars.MKDIR, directory)
    if not fs.is_dir(directory) then
       return false, "failed making directory "..directory
    end
@@ -58,7 +58,15 @@ end
 -- @param directory string: pathname of directory to remove.
 function tools.remove_dir_tree_if_empty(directory)
    assert(directory)
-   fs.execute_quiet(vars.RMDIR, directory)
+   while true do
+      fs.execute_quiet(vars.RMDIR, directory)
+      local parent = dir.dir_name(directory)
+      if parent ~= directory then
+         directory = parent
+      else
+         break
+      end
+   end
 end
 
 --- Copy a file.
@@ -271,12 +279,22 @@ function tools.set_permissions(filename, mode, scope)
 
       local ok
       -- Grant permissions available to all users
-      ok = fs.execute_quiet(vars.ICACLS .. " " .. fs.Q(filename) .. " /inheritance:d /grant:r Everyone:" .. others_perms)
+      ok = fs.execute_quiet(vars.ICACLS .. " " .. fs.Q(filename) .. " /inheritance:d /grant:r *S-1-1-0:" .. others_perms)
       if not ok then
          return false, "Failed setting permission " .. mode .. " for " .. scope
       end
+
       -- Grant permissions available only to the current user
-      ok = fs.execute_quiet(vars.ICACLS .. " " .. fs.Q(filename) .. " /inheritance:d /grant %USERNAME%:" .. my_perms)
+      ok = fs.execute_quiet(vars.ICACLS .. " " .. fs.Q(filename) .. " /inheritance:d /grant \"%USERNAME%\":" .. my_perms)
+
+      -- This may not be necessary if the above syntax is correct,
+      -- but I couldn't really test the extra quotes above, so if that
+      -- fails we try again with the syntax used in previous releases
+      -- just to be on the safe side
+      if not ok then
+         ok = fs.execute_quiet(vars.ICACLS .. " " .. fs.Q(filename) .. " /inheritance:d /grant %USERNAME%:" .. my_perms)
+      end
+
       if not ok then
          return false, "Failed setting permission " .. mode .. " for " .. scope
       end
@@ -298,4 +316,13 @@ function tools.set_time(filename, time)
    return true -- FIXME
 end
 
+function tools.lock_access(dirname)
+   -- NYI
+   return {}
+end
+
+function tools.unlock_access(lock)
+   -- NYI
+end
+
 return tools
